pub fn parse(content: &str) -> Result<(Frontmatter, &str)>Expand description
Parse YAML frontmatter from a document. Returns (frontmatter, body). If no frontmatter block is present, returns defaults and the full content as body.
pub fn parse(content: &str) -> Result<(Frontmatter, &str)>Parse YAML frontmatter from a document. Returns (frontmatter, body). If no frontmatter block is present, returns defaults and the full content as body.