pub fn write(fm: &Frontmatter, body: &str) -> Result<String>Expand description
Write frontmatter back into a document, preserving the body.
pub fn write(fm: &Frontmatter, body: &str) -> Result<String>Write frontmatter back into a document, preserving the body.