Structs
- CrdtDoc
- CRDT document wrapping a Yjs
Docfor conflict-free merging.
Functions
- compact
- Compact a CRDT state by re-encoding (GC tombstones where possible).
- dedup_
adjacent_ blocks - Remove identical adjacent text blocks separated by blank lines.
- merge
- Merge two concurrent text versions against a common base using CRDT.